@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsMessageQuestion.cc 11433 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsMessageQuestion.cc 11433 $
 // @(#) $Id: DwmDnsMessageQuestion.cc 11433 2020-12-13 06:35:55Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmDnsLabelSequence.hh"
 #include "DwmDnsMessageQuestion.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsMessageQuestion.cc 11433 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsMessageQuestion.cc 11433 $");
 
 using namespace std;
 
