@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataLOC.cc 12365 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataLOC.cc 12365 $
 // @(#) $Id: DwmDnsRRDataLOC.cc 12365 2024-05-22 21:47:33Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmDnsRRDataLOC.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataLOC.cc 12365 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataLOC.cc 12365 $");
 
 using namespace std;
 
