@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataSRV.cc 10133 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataSRV.cc 10133 $
 // @(#) $Id: DwmDnsRRDataSRV.cc 10133 2018-01-27 17:41:32Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmDnsLabelSequence.hh"
 #include "DwmDnsRRDataSRV.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataSRV.cc 10133 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataSRV.cc 10133 $");
 
 using namespace std;
 
