@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsResourceRecord.cc 10076 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsResourceRecord.cc 10076 $
 // @(#) $Id: DwmDnsResourceRecord.cc 10076 2018-01-25 03:50:31Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -47,7 +47,7 @@
 #include "DwmDnsRRData.hh"
 #include "DwmDnsResourceRecord.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsResourceRecord.cc 10076 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsResourceRecord.cc 10076 $");
 
 using namespace std;
 
