@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsLabelSequence.cc 9953 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsLabelSequence.cc 9953 $
 // @(#) $Id: TestDnsLabelSequence.cc 9953 2018-01-10 01:00:12Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -47,7 +47,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmDnsLabelSequence.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsLabelSequence.cc 9953 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsLabelSequence.cc 9953 $");
 
 using namespace std;
 using namespace Dwm;
