@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsMessageHeader.cc 9995 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsMessageHeader.cc 9995 $
 // @(#) $Id: TestDnsMessageHeader.cc 9995 2018-01-13 01:57:10Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -43,7 +43,7 @@
 #include "DwmUnitAssert.hh"
 #include "DwmDnsMessageHeader.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsMessageHeader.cc 9995 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsMessageHeader.cc 9995 $");
 
 using namespace std;
 using namespace Dwm;
