@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmUnitAssert.hh"
 #include "DwmDnsNameServer.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsNameServer.cc 10734 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsNameServer.cc 10734 $");
 
 using namespace std;
 using namespace Dwm;
