@@ -44,7 +44,7 @@
 #include "DwmDnsResolver.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsResolver.cc 10069 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsResolver.cc 10069 $");
 
 using namespace std;
 using namespace Dwm;
